@@ -48,7 +48,7 @@ extern "C"
 {
 	KDE_EXPORT QWidget* allocate_kstyle_config(QWidget* parent)
 	{
-		KGlobal::locale()->insertCatalogue("kstyle_polyester_config");
+		KGlobal::locale()->insertCatalogue("polyester");
 		return new PolyesterStyleConfig(parent);
 	}
 }
@@ -75,6 +75,7 @@ PolyesterStyleConfig::PolyesterStyleConfig(QWidget* parent): QWidget(parent)
 	origScrollBarSize = s.readNumEntry("/polyesterstyle/Settings/scrollBarSize", 16);
 	dialog_->scrollBarSize->setValue(origScrollBarSize);
 	origCenteredTabBar = s.readBoolEntry("/polyesterstyle/Settings/centeredTabBar", false);
+        dialog_->centeredTabBar->setChecked(origCenteredTabBar);
 	origHighLightTab = s.readBoolEntry("/polyesterstyle/Settings/highLightTab", true);
 	dialog_->highLightTab->setChecked(origHighLightTab);
 	origStatusBarFrame = s.readBoolEntry("/polyesterstyle/Settings/statusBarFrame", true);
